@@ -1,4 +1,4 @@
-"""DC Tabular Application Profiles (DCTAP) - base module"""
+"""DC Tabular Application Profiles (DCTAP) command-line utility."""
 
 import sys
 import json as j
@@ -9,6 +9,7 @@ from .config import get_config, write_configfile
 from .csvreader import csvreader
 from .inspect import pprint_tapshapes, print_warnings
 from .loggers import stderr_logger
+from .tapclasses import TAPShape, TAPStatementTemplate
 from .utils import expand_uri_prefixes
 
 # pylint: disable=unused-argument,no-value-for-parameter
@@ -17,7 +18,7 @@ from .utils import expand_uri_prefixes
 
 
 @click.group()
-@click.version_option("0.3.13", help="Show version and exit")
+@click.version_option("0.3.15", help="Show version and exit")
 @click.help_option(help="Show help and exit")
 @click.pass_context
 def cli(context):
@@ -26,17 +27,15 @@ def cli(context):
     Examples (see https://dctap-python.rtfd.io):
 
     \b
-    Write an editable configuration file:
+    Write starter config file:
     $ dctap init                           # Write dctap.yaml
     $ dctap init --hidden                  # Write .dctaprc
     \b
-    Parse a CSV and generate a normalized view:
+    Show normalized view of TAP:
     $ dctap read x.csv                     # Output as plain text
     $ dctap read --json x.csv              # Output as JSON
     $ dctap read --yaml x.csv              # Output as YAML
-    $ dctap read --expand-prefixes x.csv   # Expand prefixes
-    $ dctap read --warnings x.csv          # Show warnings
-    $ dctap read --config ../taprc x.csv   # Point to a configfile
+    $ dctap read --warnings x.csv          # Also show warnings
     """
 
 
@@ -63,11 +62,17 @@ def init(context, hidden):
 @click.help_option(help="Show help and exit")
 @click.pass_context
 def read(context, csvfile_obj, config, expand_prefixes, warnings, json, yaml):
-    """Normalize TAP to text, JSON, or YAML."""
+    """Show TAP as TXT, JSON, or YAML."""
     # pylint: disable=too-many-locals,too-many-arguments
 
     config_dict = get_config(configfile_name=config)
-    tapshapes_dict = csvreader(csvfile_obj, config_dict)
+    tapshapes_dict = csvreader(
+        open_csvfile_obj=csvfile_obj,
+        config_dict=config_dict,
+        shape_class=TAPShape,
+        state_class=TAPStatementTemplate,
+    )
+
     if expand_prefixes:
         tapshapes_dict = expand_uri_prefixes(tapshapes_dict, config_dict)
 
@@ -91,7 +96,12 @@ def read(context, csvfile_obj, config, expand_prefixes, warnings, json, yaml):
         y.dump(tapshapes_dict, sys.stdout)
 
     if not (json or yaml):
-        pprint_output = pprint_tapshapes(tapshapes_dict, config_dict)
+        pprint_output = pprint_tapshapes(
+            tapshapes_dict=tapshapes_dict,
+            config_dict=config_dict,
+            shape_class=TAPShape,
+            state_class=TAPStatementTemplate,
+        )
         for line in pprint_output:
             print(line, file=sys.stdout)
         if warnings:
