@@ -1,20 +1,30 @@
-"""Parse DCTAP/CSV, return two-item tuple: (list of shape objects, list of warnings)."""
+"""Parse TAP, return two-item tuple: (list of shape objects, list of warnings)."""
 
 import re
+import sys
 from collections import defaultdict
 from csv import DictReader
 from io import StringIO as StringBuffer
 from dataclasses import asdict
 from .config import get_shems, get_stems
 from .exceptions import DctapError
-from .tapclasses import TAPShape, TAPStatementTemplate
 from .utils import coerce_concise
 
 
-def csvreader(open_csvfile_obj, config_dict):
+def csvreader(
+    open_csvfile_obj=None, config_dict=None, shape_class=None, state_class=None
+):
     """From open CSV file object, return shapes dict."""
     (csvrows, csvwarns) = _get_rows(open_csvfile_obj, config_dict)
-    (tapshapes, tapwarns) = _get_tapshapes(csvrows, config_dict)
+    if csvrows:
+        (tapshapes, tapwarns) = _get_tapshapes(
+            rows=csvrows,
+            config_dict=config_dict,
+            shape_class=shape_class,
+            state_class=state_class,
+        )
+    else:
+        sys.exit("No data to process.")
     tapwarns = {**csvwarns, **tapwarns}
     tapshapes = _add_namespaces(tapshapes, config_dict, csvrows)
     tapshapes = _add_tapwarns(tapshapes, tapwarns)
@@ -96,7 +106,7 @@ def _get_rows(open_csvfile_obj, config_dict):
     return (csv_rows, csv_warns)
 
 
-def _get_tapshapes(rows, config_dict):
+def _get_tapshapes(rows=None, config_dict=None, shape_class=None, state_class=None):
     """Return tuple: (shapes dict, warnings dict)."""
     # pylint: disable=too-many-locals
     # pylint: disable=too-many-branches
@@ -107,7 +117,9 @@ def _get_tapshapes(rows, config_dict):
     except KeyError:
         dshape = "default"
 
-    (main_stems, xtra_stems) = get_stems(TAPStatementTemplate, config_dict)
+    (main_stems, xtra_stems) = get_stems(
+        state_class=state_class, config_dict=config_dict
+    )
 
     shapes = {}  # dict for shapeID-to-TAPShape_list
     warns = defaultdict(dict)  # dict for shapeID-to-warnings_list
@@ -127,7 +139,7 @@ def _get_tapshapes(rows, config_dict):
 
         if sh_id:
             if sh_id not in list(shapes):
-                sh_obj = _mkshape(row, config_dict)
+                sh_obj = _mkshape(row_dict=row, config_dict=config_dict, shape_class=shape_class)
                 sh_obj.normalize(config_dict)
                 shapes[sh_id] = sh_obj
                 warns[sh_id] = {}
@@ -143,16 +155,16 @@ def _get_tapshapes(rows, config_dict):
         if not row.get("propertyID"):
             continue
 
-        st = TAPStatementTemplate()
+        st_obj = state_class()
         for col in row:
             if col in main_stems:
-                setattr(st, col, row[col])
+                setattr(st_obj, col, row[col])
             elif col in xtra_stems:
-                st.state_extras[col] = row[col]
+                st_obj.state_extras[col] = row[col]
 
-        st.normalize(config_dict)
-        shapes[sh_id].state_list.append(st)
-        st_warns = st.get_warnings()
+        st_obj.normalize(config_dict)
+        shapes[sh_id].state_list.append(st_obj)
+        st_warns = st_obj.get_warnings()
 
         for (elem, warn) in st_warns.items():
             try:
@@ -163,21 +175,20 @@ def _get_tapshapes(rows, config_dict):
 
         warns_dict = dict(warns)
         shapes_dict = {}
-        list_of_shapes = []
-        shapes_dict["shapes"] = list_of_shapes
+        shapes_dict["shapes"] = []
 
         for sh_obj in list(shapes.values()):
             sh_dict = asdict(sh_obj)
             sh_dict["statement_templates"] = sh_dict.pop("state_list")
-            list_of_shapes.append(sh_dict)
+            shapes_dict["shapes"].append(sh_dict)
 
         shapes_dict = _simplify(shapes_dict)
 
     return (shapes_dict, warns_dict)
 
 
-def _mkshape(row_dict=None, config_dict=None):
-    """Populates shape fields of dataclass TAPShape object from dict for one row.
+def _mkshape(row_dict=None, config_dict=None, shape_class=None):
+    """Populates shape fields of dataclass shape object from dict for one row.
 
     Args:
         row_dict: Dictionary of all columns headers (keys) and cell values (values)
@@ -186,18 +197,11 @@ def _mkshape(row_dict=None, config_dict=None):
         config_dict: Dictionary of settings, built-in or as read from config file.
 
     Returns:
-        Unpopulated instance of dctap.tapclasses.TAPShape, by default:
-        - TAPShape(
-              shapeID='',
-              shapeLabel='',
-              state_list=[],
-              shape_warns={},
-              state_extras={}
-          )
-        - Plus extra TAPShape fields as per config settings.
+        Unpopulated instance of shape class, for example:
+        TAPShape(shapeID='', state_list=[], shape_warns={}, state_extras={}, ...)
     """
-    (main_shems, xtra_shems) = get_shems(shape_class=TAPShape, settings=config_dict)
-    tapshape_obj = TAPShape()
+    (main_shems, xtra_shems) = get_shems(shape_class=shape_class, config_dict=config_dict)
+    tapshape_obj = shape_class()
     for key in row_dict:
         if key in main_shems:
             setattr(tapshape_obj, key, row_dict[key])
@@ -207,12 +211,7 @@ def _mkshape(row_dict=None, config_dict=None):
 
 
 def _normalize_element_name(some_str, element_aliases_dict=None):
-    """
-    Given an element name (string),
-    If name is recognized
-    If not, leave unchanged.
-    """
-
+    """Given header string, return converted if aliased, else return unchanged."""
     some_str = coerce_concise(some_str)
     if element_aliases_dict:
         for key in element_aliases_dict.keys():
