@@ -26,73 +26,51 @@ class TAPStatementTemplate:
     state_warns: dict = field(default_factory=dict)
     state_extras: dict = field(default_factory=dict)
 
-    def normalize(self, settings):
+    def normalize(self, config_dict):
         """Normalizes specific fields."""
         # pylint: disable=attribute-defined-outside-init
-        self._warn_if_propertyID_not_IRIlike()
-        self._warn_if_valueDataType_not_IRIlike()
-        self._normalize_booleans_mandatory_repeatable()
+        self._normalize_booleans()
         self._valueConstraintType_pattern_warn_if_valueConstraint_not_valid_regex()
         self._valueConstraintType_pattern_warn_if_used_with_value_shape()
         self._valueConstraintType_iristem_parse()
         self._valueConstraintType_iristem_warn_if_list_items_not_IRIs()
-        self._valueConstraintType_languageTag_parse(settings)
-        self._valueConstraintType_minmaxlength_parse()
-        self._valueConstraintType_minmaxlength_warn_if_not_integer()
+        self._valueConstraintType_languageTag_parse(config_dict)
+        self._valueConstraintType_minmaxlength_warn_if_not_nonnegative_integer()
         self._valueConstraintType_minmaxinclusive_parse()
         self._valueConstraintType_minmaxinclusive_warn_if_value_not_numeric()
         self._valueConstraintType_warn_if_used_without_valueConstraint()
         self._valueDataType_warn_if_used_with_valueNodeType_IRI()
         self._valueDataType_warn_if_valueNodeType_literal_used_with_any_valueShape()
-        self._valueConstraintType_picklist_parse(settings)
-        self._valueNodeType_is_from_enumerated_list(settings)
-        self._parse_elements_configured_as_picklist_elements(settings)
+        self._valueConstraintType_picklist_parse(config_dict)
+        self._valueNodeType_is_from_enumerated_list(config_dict)
+        self._parse_elements_configured_as_picklist_elements(config_dict)
         return self
 
-    def _warn_if_propertyID_not_IRIlike(self):
-        """Records warning if propertyID or valueDataType are not IRI-like."""
-        if not is_uri_or_prefixed_uri(self.propertyID):
-            self.state_warns[
-                "propertyID"
-            ] = f"{repr(self.propertyID)} is not an IRI or Compact IRI."
-
-    def _warn_if_valueDataType_not_IRIlike(self):
-        if self.valueDataType:
-            if not is_uri_or_prefixed_uri(self.valueDataType):
-                self.state_warns[
-                    "valueDataType"
-                ] = f"{repr(self.valueDataType)} is not an IRI or Compact IRI."
-
-    def _normalize_booleans_mandatory_repeatable(self):
-        """Booleans take true/false (case-insensitive) or 1/0, default None."""
-
-        valid_values_for_true = ["true", "1"]
-        valid_values_for_false = ["false", "0"]
-        valid_values = valid_values_for_true + valid_values_for_false
-
-        # pylint: disable=singleton-comparison
-        if self.mandatory:
-            mand = self.mandatory.lower()
-            if mand not in valid_values:
-                self.state_warns[
-                    "mandatory"
-                ] = f"{repr(self.mandatory)} is not a supported Boolean value."
-            if mand in valid_values_for_true:
-                self.mandatory = "true"
-            elif mand in valid_values_for_false:
-                self.mandatory = "false"
-
-        if self.repeatable:
-            repeat = self.repeatable.lower()
-            if repeat not in valid_values:
-                self.state_warns[
-                    "repeatable"
-                ] = f"{repr(self.repeatable)} is not a supported Boolean value."
-            if repeat in valid_values_for_true:
-                self.repeatable = "true"
-            elif repeat in valid_values_for_false:
-                self.repeatable = "false"
+    def _warn_if_value_not_urilike(self):
+        """Warns when values of given elements do not look like URIs."""
+        elements_that_may_take_uris = {
+            "propertyID": self.propertyID,
+            "valueDataType": self.valueDataType,
+        }
+        for (elem, statefield) in elements_that_may_take_uris.items():
+            if statefield:
+                if not is_uri_or_prefixed_uri(statefield):
+                    self.state_warns[elem] = f"{repr(elem)} is not IRI or Compact IRI."
 
+    def _normalize_booleans(self):
+        """Coerces supported Boolean values to 'true' or 'false' or leaves unchanged."""
+        valid_values_for_true = ["true", "TRUE", "True", "1"]
+        valid_values_for_false = ["false", "FALSE", "False", "0"]
+        boolean_elements = ["mandatory", "repeatable"]
+        for elem in boolean_elements:
+            warning_message = f"{repr(elem)} is not a supported Boolean value."
+            if getattr(self, elem):
+                if getattr(self, elem) in valid_values_for_true:
+                    setattr(self, elem, "true")
+                elif getattr(self, elem) in valid_values_for_false:
+                    setattr(self, elem, "false")
+                else:
+                    self.state_warns[elem] = warning_message
         return self
 
     def _valueConstraintType_iristem_parse(self):
@@ -116,26 +94,24 @@ class TAPStatementTemplate:
                     )
         return self
 
-    def _valueConstraintType_minmaxlength_parse(self):
-        """valueConstraintType minLength: coerce integer (or return string)."""
-        self.valueConstraintType = self.valueConstraintType.lower()
-        value_constraint = self.valueConstraint
-        if self.valueConstraintType in ("minlength", "maxlength"):
-            if value_constraint:
-                self.valueConstraint = coerce_integer(value_constraint)
-        return self
+    def _valueConstraintType_minmaxlength_warn_if_not_nonnegative_integer(self):
+        """
+        Tries to coerce valueConstraint to integer (or leaves string untouched).
+        Warns if valueConstraint for minLength is not a nonnegative integer.
+        """
+        vctype = self.valueConstraintType.lower()
+        vc = self.valueConstraint = coerce_integer(self.valueConstraint)
+        bad_vc_warning = (
+            f"Value constraint type is {repr(self.valueConstraintType)}, "
+            f"but {repr(self.valueConstraint)} is not a positive integer."
+        )
+        if vctype in ("minlength", "maxlength"):
+            if isinstance(vc, int):
+                if vc < 0:
+                    self.state_warns["valueConstraint"] = bad_vc_warning
+            elif not isinstance(vc, int):
+                self.state_warns["valueConstraint"] = bad_vc_warning
 
-    def _valueConstraintType_minmaxlength_warn_if_not_integer(self):
-        """Warns if valueConstraint minLength not a nonnegative integer."""
-        self.valueConstraintType = self.valueConstraintType.lower()
-        if self.valueConstraintType in ("minlength", "maxlength"):
-            try:
-                int(self.valueConstraint)
-            except (ValueError, TypeError):
-                self.state_warns["valueConstraint"] = (
-                    f"Value constraint type is {repr(self.valueConstraintType)}, "
-                    f"but {repr(self.valueConstraint)} is not an integer."
-                )
         return self
 
     def _valueConstraintType_minmaxinclusive_parse(self):
@@ -187,10 +163,10 @@ class TAPStatementTemplate:
                     "cannot conform to a value shape."
                 )
 
-    def _valueConstraintType_languageTag_parse(self, settings):
+    def _valueConstraintType_languageTag_parse(self, config_dict):
         """For valueConstraintType languageTag, splits valueConstraint on whitespace."""
         self.valueConstraintType = self.valueConstraintType.lower()
-        sep = settings.get("picklist_item_separator", " ")
+        sep = config_dict.get("picklist_item_separator", " ")
         if self.valueConstraintType == "languagetag":
             if self.valueConstraint:
                 self.valueConstraint = self.valueConstraint.split(sep)
@@ -208,22 +184,22 @@ class TAPStatementTemplate:
                 )
         return self
 
-    def _valueConstraintType_picklist_parse(self, settings):
+    def _valueConstraintType_picklist_parse(self, config_dict):
         """If valueConstraintType is Picklist, split valueConstraint on whitespace."""
         self.valueConstraintType = self.valueConstraintType.lower()
-        sep = settings.get("picklist_item_separator", " ")
+        sep = config_dict.get("picklist_item_separator", " ")
         if self.valueConstraintType == "picklist":
             if self.valueConstraint:
                 self.valueConstraint = self.valueConstraint.split(sep)
                 self.valueConstraint = [x.strip() for x in self.valueConstraint if x]
         return self
 
-    def _valueNodeType_is_from_enumerated_list(self, settings):
+    def _valueNodeType_is_from_enumerated_list(self, config_dict):
         """Take valueNodeType from configurable enumerated list, case-insensitive."""
         warning = f"{repr(self.valueNodeType)} is not a valid node type."
         valid_types = ["iri", "bnode", "literal"]
-        if settings.get("value_node_types"):
-            valid_types += [vnt.lower() for vnt in settings["value_node_types"]]
+        if config_dict.get("value_node_types"):
+            valid_types += [vnt.lower() for vnt in config_dict["value_node_types"]]
         if self.valueNodeType:
             self.valueNodeType = self.valueNodeType.lower()  # normalize to lowercase
             if self.valueNodeType not in valid_types:
@@ -256,17 +232,17 @@ class TAPStatementTemplate:
                 self.state_warns["valueDataType"] = warning
         return self
 
-    def _parse_elements_configured_as_picklist_elements(self, settings):
+    def _parse_elements_configured_as_picklist_elements(self, config_dict):
         """Parse elements configured as list elementss."""
-        if settings.get("picklist_item_separator"):
-            separator = settings.get("picklist_item_separator")
+        if config_dict.get("picklist_item_separator"):
+            separator = config_dict.get("picklist_item_separator")
         else:
             separator = " "
 
-        if settings.get("list_elements"):
-            picklist_elements = settings.get("list_elements")
-        elif settings.get("picklist_elements"):
-            picklist_elements = settings.get("picklist_elements")
+        if config_dict.get("list_elements"):
+            picklist_elements = config_dict.get("list_elements")
+        elif config_dict.get("picklist_elements"):
+            picklist_elements = config_dict.get("picklist_elements")
         else:
             picklist_elements = []
 
@@ -294,17 +270,26 @@ class TAPShape:
     shape_warns: dict = field(default_factory=dict)
     shape_extras: dict = field(default_factory=dict)
 
-    def normalize(self, settings):
+    def normalize(self, config_dict):
         """Normalize values where required."""
-        self._normalize_default_shapeID(settings)
+        self._normalize_default_shapeID(config_dict)
+        self._warn_if_value_not_urilike()
         return True
 
-    def _normalize_default_shapeID(self, settings):
+    def _normalize_default_shapeID(self, config_dict):
         """If shapeID not specified, looks first in config, else sets "default"."""
         if not self.shapeID:
-            self.shapeID = settings.get("default_shape_identifier", "default")
+            self.shapeID = config_dict.get("default_shape_identifier", "default")
         return self
 
+    def _warn_if_value_not_urilike(self):
+        """Warns when values of given elements do not look like URIs."""
+        elements_that_may_take_uris = {"shapeID": self.shapeID}
+        for (elem, shapefield) in elements_that_may_take_uris.items():
+            if shapefield:
+                if not is_uri_or_prefixed_uri(shapefield):
+                    self.shape_warns[elem] = f"{repr(elem)} is not IRI or Compact IRI."
+
     def get_warnings(self):
         """Emit warnings dictionary self.shape_warns, populated by normalize() method."""
         return dict(self.shape_warns)
