@@ -9,12 +9,11 @@ Languages are most commonly designated using the ISO 639 standard codes." [1]
 [1] https://www.loc.gov/standards/iso639-2/langhome.html
 """
 
-
 import os
 import pytest
 from pathlib import Path
 from dctap.config import get_config
-from dctap.tapclasses import TAPStatementTemplate
+from dctap.tapclasses import TAPShape, TAPStatementTemplate
 from dctap.csvreader import csvreader
 
 
@@ -42,7 +41,12 @@ def test_valueConstraintType_languagetag_item_separator_comma(tmp_path):
             'ex:foo,languagetag,"fr, it, de"\n'
         )
     )
-    value_constraint = csvreader(open(csvfile_path), config_dict)["shapes"][0]["statement_templates"][0]["valueConstraint"]
+    value_constraint = csvreader(
+        open_csvfile_obj=open(csvfile_path), 
+        config_dict=config_dict,
+        shape_class=TAPShape,
+        state_class=TAPStatementTemplate,
+    )["shapes"][0]["statement_templates"][0]["valueConstraint"]
     assert value_constraint == ["fr", "it", "de"]
 
 
@@ -59,6 +63,11 @@ def test_valueConstraintType_languagetag_item_separator_pipe(tmp_path):
             'ex:foo,languagetag,"fr|it|de"\n'
         )
     )
-    value_constraint = csvreader(open(csvfile_path), config_dict)["shapes"][0]["statement_templates"][0]["valueConstraint"]
+    value_constraint = csvreader(
+        open_csvfile_obj=open(csvfile_path), 
+        config_dict=config_dict,
+        shape_class=TAPShape,
+        state_class=TAPStatementTemplate,
+    )["shapes"][0]["statement_templates"][0]["valueConstraint"]
     assert value_constraint == ["fr", "it", "de"]
 
